@@ -6,7 +6,7 @@ use std::time::Duration;
 use clickhouse_rs::{ClientHandle, Options, Pool};
 use rlink::channel::utils::handover::Handover;
 use rlink::core::checkpoint::CheckpointFunction;
-use rlink::core::element::Record;
+use rlink::core::element::{FnSchema, Record};
 use rlink::core::function::{Context, NamedFunction, OutputFormat};
 use rlink::utils::thread::{async_runtime, async_sleep, async_spawn};
 use rlink::{core, utils};
@@ -93,6 +93,10 @@ impl OutputFormat for ClickhouseSink {
     fn close(&mut self) -> core::Result<()> {
         Ok(())
     }
+
+    fn schema(&self, _input_schema: FnSchema) -> FnSchema {
+        FnSchema::Empty
+    }
 }
 
 impl CheckpointFunction for ClickhouseSink {}
